@@ -1,7 +1,7 @@
 package WordList;
 
-our $DATE = '2016-01-07'; # DATE
-our $VERSION = '0.1.0'; # VERSION
+our $DATE = '2016-01-12'; # DATE
+our $VERSION = '0.1.1'; # VERSION
 
 use strict 'subs', 'vars';
 
@@ -85,9 +85,27 @@ sub word_exists {
     0;
 }
 
+sub all_words {
+    my ($self) = @_;
+
+    my $class = ref($self);
+
+    my $fh = \*{"$class\::DATA"};
+
+    seek $fh, ${"$class\::DATA_POS"}, 0;
+    my @res;
+    while (defined(my $word = <$fh>)) {
+        chomp $word;
+        push @res, $word;
+    }
+    @res;
+}
+
 1;
 # ABSTRACT: Word lists
 
+
+
 __END__
 
 =pod
@@ -100,7 +118,7 @@ WordList - Word lists
 
 =head1 VERSION
 
-This document describes version 0.1.0 of WordList (from Perl distribution WordList), released on 2016-01-07.
+This document describes version 0.1.1 of WordList (from Perl distribution WordList), released on 2016-01-12.
 
 =head1 SYNOPSIS
 
@@ -116,7 +134,9 @@ modules.
 
 C<WordList> is an alternative interface for L<Games::Word::Wordlist> and
 C<Games::Word::Wordlist::*>. Its main difference is: C<WordList::*> modules are
-designed to have low startup overhead and optimized for use in CLI scripts.
+designed to have low startup overhead. This makes it more suitable for use in
+CLI scripts which often only want to pick a word from one or several lists.
+
 Words (or phrases) must be put in __DATA__ section, *sorted*, one per line. By
 putting it in the __DATA__ section, perl doesn't have to parse the list. To
 search for words or picking some random words from the list, the module need not
@@ -144,6 +164,8 @@ The methods provided are just:
 
 - C<each_word> (run code for each entry)
 
+- C<all_words> (return all the words in a list)
+
 A couple of other functions might be added, with careful consideration.
 
 =item * Namespace is more language-neutral and not English-centric
@@ -190,6 +212,10 @@ Check whether C<$word> is in the list.
 
 Algorithm is binary search (NOTE: not yet implemented, currently linear search).
 
+=head2 $wl->all_words() => list
+
+Return all the words in a list.
+
 =head1 SEE ALSO
 
 L<Bencher::Scenario::GamesWordlistModules>
@@ -224,3 +250,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
